# -*- coding: utf_8_sig -*-

# Copyright © 2018 by IBPort. All rights reserved.
# @Author: Neal Wong
# @Email: ibprnd@gmail.com

import os
from io import open
from glob import glob
import json

from mws.mws import DictWrapper
from dropshipping.utils import ObjectDict

import six
import pytest

@pytest.fixture(scope='session')
def mws_pages_dir():
    return os.path.join(os.path.dirname(os.path.abspath(__file__)), 'mws', 'pages')

@pytest.fixture(scope='session')
def es_service_pages_dir():
    return os.path.join(os.path.dirname(os.path.abspath(__file__)), 'es_services', 'pages')

@pytest.fixture(scope='session')
def mws_lowest_offer_listings_for_asin(mws_pages_dir):
    results = []

    file_pathes = glob('{}/lowest_offer_listings_for_asin*.xml'.format(mws_pages_dir))
    for file_path in file_pathes:
        with open(file_path, encoding='utf_8_sig', errors='ignore') as fh:
            results.append(DictWrapper(fh.read(), 'GetLowestOfferListingsForASINResult'))

    return results

@pytest.fixture(scope='session')
def mws_competitive_pricing_for_asin(mws_pages_dir):
    results = []

    file_pathes = glob('{}/competitive_pricing_for_asin*.xml'.format(mws_pages_dir))
    for file_path in file_pathes:
        with open(file_path, encoding='utf_8_sig', errors='ignore') as fh:
            results.append(DictWrapper(fh.read(), 'GetCompetitivePricingForASINResult'))

    return results

@pytest.fixture
def mws_invalid_seller_id_response(mws_pages_dir):
    file_path = os.path.join(mws_pages_dir, 'wrong_seller_id.xml')
    with open(file_path, encoding='utf_8_sig', errors='ignore') as fh:
        response = ObjectDict({'text': fh.read()})
        yield response

@pytest.fixture
def mws_invalid_access_key_id_response(mws_pages_dir):
    file_path = os.path.join(mws_pages_dir, 'invalid_access_key_id.xml')
    with open(file_path, encoding='utf_8_sig', errors='ignore') as fh:
        response = ObjectDict({'text': fh.read()})
        yield response

@pytest.fixture
def es_lowest_offer_listings(es_service_pages_dir):
    file_path = os.path.join(es_service_pages_dir, 'lowest_offer_listings_response.json')
    with open(file_path, encoding='utf_8_sig', errors='ignore') as fh:
        yield json.load(fh)

@pytest.fixture
def es_buy_box_offer(es_service_pages_dir):
    file_path = os.path.join(es_service_pages_dir, 'buybox_offer_response.json')
    with open(file_path, encoding='utf_8_sig', errors='ignore') as fh:
        yield json.load(fh)

@pytest.fixture
def es_sales_ranks(es_service_pages_dir):
    results = []

    file_path = os.path.join(es_service_pages_dir, 'sales_ranks_response.json')
    with open(file_path, encoding='utf_8_sig', errors='ignore') as fh:
        yield json.load(fh)

@pytest.fixture
def es_matching_products(es_service_pages_dir):
    results = []

    file_path = os.path.join(es_service_pages_dir, 'matching_products_response.json')
    with open(file_path, encoding='utf_8_sig', errors='ignore') as fh:
        yield json.load(fh)

@pytest.fixture
def mws_matching_products(mws_pages_dir):
    results = []

    file_pathes = glob('{}/get_matching_product*.xml'.format(mws_pages_dir))
    for file_path in file_pathes:
        with open(file_path, 'rb') as fh:
            c = fh.read()
            if six.PY2:
                c = unicode(c, 'utf-8').encode('utf-8')
            else:
                c = c.decode('utf-8')
            results.append(DictWrapper(c, 'GetMatchingProductResult'))

    return results

@pytest.fixture
def mws_product_categories(mws_pages_dir):
    results = []

    file_pathes = glob('{}/get_product_categories*.xml'.format(mws_pages_dir))
    for file_path in file_pathes:
        with open(file_path, 'rb') as fh:
            c = fh.read()
            if six.PY2:
                c = unicode(c, 'utf-8').encode('utf-8')
            else:
                c = c.decode('utf-8')
            results.append(DictWrapper(c, 'GetProductCategoriesForASINResult'))

    return results

@pytest.fixture
def es_product_categories(es_service_pages_dir):
    results = []

    file_path = os.path.join(es_service_pages_dir, 'product_categories_response.json')
    with open(file_path, encoding='utf_8_sig', errors='ignore') as fh:
        yield json.load(fh)

@pytest.fixture
def mws_request_report_result(mws_pages_dir):
    file_path = os.path.join(mws_pages_dir, 'request_report.xml')
    with open(file_path, 'rb') as fh:
        c = fh.read()
        if six.PY2:
            c = unicode(c, 'utf-8').encode('utf-8')
        else:
            c = c.decode('utf-8')

        yield DictWrapper(c, 'RequestReportResult')

@pytest.fixture
def mws_report_request_list_result(mws_pages_dir):
    file_path = os.path.join(mws_pages_dir, 'get_report_request_list.xml')
    with open(file_path, 'rb') as fh:
        c = fh.read()
        if six.PY2:
            c = unicode(c, 'utf-8').encode('utf-8')
        else:
            c = c.decode('utf-8')

        yield DictWrapper(c, 'GetReportRequestListResult')

@pytest.fixture
def mws_report_list_result(mws_pages_dir):
    file_path = os.path.join(mws_pages_dir, 'get_report_list.xml')
    with open(file_path, 'rb') as fh:
        c = fh.read()
        if six.PY2:
            c = unicode(c, 'utf-8').encode('utf-8')
        else:
            c = c.decode('utf-8')

        yield DictWrapper(c, 'GetReportListResult')

@pytest.fixture
def config_dir():
    return os.path.join(os.path.dirname(os.path.abspath(__file__)), 'utils', 'data')

@pytest.fixture
def file_config_path(config_dir):
    return os.path.join(config_dir, 'file_config.txt')

@pytest.fixture
def ini_config_path(config_dir):
    return os.path.join(config_dir, 'ini_config.ini')

@pytest.fixture
def yaml_config_path(config_dir):
    return os.path.join(config_dir, 'yaml_config.yml')

@pytest.fixture(scope='session')
def raw_offer():
    return {
        'asin': '0811867188',
        'country': 'us',
        'product_price': 6.36,
        'shipping_price': 3.94,
        'price': 10.30,
        'currency': 'USD',
        'condition': 'Used',
        'subcondition': 'Good'
    }

@pytest.fixture(scope='session')
def lowest_offer_listing_offer():
    return {
        'asin': '0811867188',
        'country': 'us',
        'product_price': 6.36,
        'shipping_price': 3.94,
        'price': 10.30,
        'currency': 'USD',
        'condition': 'Used',
        'subcondition': 'Good',
        'shipping_time': {
            'min': 0,
            'max': 2
        },
        'rating': {
            'min': 95,
            'max': 97
        },
        'feedback': 68573,
        'domestic': True,
        'fba': False,
    }

@pytest.fixture(scope='session')
def buybox_offer():
    return {
        'asin': '0811867188',
        'country': 'us',
        'condition': 'Used',
        'subcondition': 'Good',
        'currency': 'USD',
        'product_price': 17.17,
        'shipping_price': 0,
        'price': 17.17,
        'belongs_to_requester': False,
        'seller_id': 'A178ZFSTAXZSA7'
    }

@pytest.fixture(scope='session')
def target_lowest_offer_listing_offers():
    target_offers = {
        '0811867188': [
            {
                'asin': '0811867188',
                'country': 'us',
                'condition': 'Used',
                'subcondition': 'Good',
                'product_price': 6.36,
                'shipping_price': 3.94,
                'price': 10.30,
                'currency': 'USD',
                'shipping_time': {
                    'min': 0,
                    'max': 2
                },
                'rating': {
                    'min': 95,
                    'max': 97
                },
                'feedback': 68573,
                'domestic': True,
                'fba': False,
            },
            {
                'asin': '0811867188',
                'country': 'us',
                'condition': 'Used',
                'subcondition': 'Acceptable',
                'product_price': 10.31,
                'shipping_price': 0,
                'price': 10.31,
                'currency': 'USD',
                'shipping_time': {
                    'min': 0,
                    'max': 2
                },
                'rating': {
                    'min': 95,
                    'max': 97
                },
                'feedback': 217854,
                'domestic': True,
                'fba': False,
            },
            {
                'asin': '0811867188',
                'country': 'us',
                'condition': 'Used',
                'subcondition': 'Good',
                'product_price': 6.32,
                'shipping_price': 3.99,
                'price': 10.31,
                'currency': 'USD',
                'shipping_time': {
                    'min': 3,
                    'max': 7
                },
                'rating': {
                    'min': 95,
                    'max': 97
                },
                'feedback': 52433,
                'domestic': True,
                'fba': False,
            },
            {
                'asin': '0811867188',
                'country': 'us',
                'condition': 'Used',
                'subcondition': 'Acceptable',
                'product_price': 6.39,
                'shipping_price': 4.99,
                'price': 11.38,
                'currency': 'USD',
                'shipping_time': {
                    'min': 0,
                    'max': 2
                },
                'rating': {
                    'min': 98,
                    'max': 100
                },
                'feedback': 3225,
                'domestic': True,
                'fba': False,
            },
            {
                'asin': '0811867188',
                'country': 'us',
                'condition': 'Used',
                'subcondition': 'Mint',
                'product_price': 10.00,
                'shipping_price': 3.99,
                'price': 13.99,
                'currency': 'USD',
                'shipping_time': {
                    'min': 0,
                    'max': 2
                },
                'rating': {
                    'min': 95,
                    'max': 97
                },
                'feedback': 47682,
                'domestic': True,
                'fba': False,
            },
            {
                'asin': '0811867188',
                'country': 'us',
                'condition': 'Used',
                'subcondition': 'VeryGood',
                'product_price': 14.99,
                'shipping_price': 0,
                'price': 14.99,
                'currency': 'USD',
                'shipping_time': {
                    'min': 0,
                    'max': 2
                },
                'rating': {
                    'min': 98,
                    'max': 100
                },
                'feedback': 21231,
                'domestic': True,
                'fba': False,
            },
            {
                'asin': '0811867188',
                'country': 'us',
                'condition': 'Used',
                'subcondition': 'Good',
                'product_price': 16.48,
                'shipping_price': 0,
                'price': 16.48,
                'currency': 'USD',
                'shipping_time': {
                    'min': 0,
                    'max': 2
                },
                'rating': {
                    'min': 90,
                    'max': 94
                },
                'feedback': 4513,
                'domestic': True,
                'fba': False,
            },
            {
                'asin': '0811867188',
                'country': 'us',
                'condition': 'Used',
                'subcondition': 'Good',
                'product_price': 17.17,
                'shipping_price': 0,
                'price': 17.17,
                'currency': 'USD',
                'shipping_time': {
                    'min': 0,
                    'max': 2
                },
                'rating': {
                    'min': 95,
                    'max': 97
                },
                'feedback': 3609,
                'domestic': True,
                'fba': True,
            },
            {
                'asin': '0811867188',
                'country': 'us',
                'condition': 'Used',
                'subcondition': 'VeryGood',
                'product_price': 17.64,
                'shipping_price': 0,
                'price': 17.64,
                'currency': 'USD',
                'shipping_time': {
                    'min': 0,
                    'max': 2
                },
                'rating': {
                    'min': 90,
                    'max': 94
                },
                'feedback': 4191,
                'domestic': True,
                'fba': False,
            },
            {
                'asin': '0811867188',
                'country': 'us',
                'condition': 'Used',
                'subcondition': 'VeryGood',
                'product_price': 17.64,
                'shipping_price': 0,
                'price': 17.64,
                'currency': 'USD',
                'shipping_time': {
                    'min': 0,
                    'max': 2
                },
                'rating': {
                    'min': 90,
                    'max': 94
                },
                'feedback': 456,
                'domestic': True,
                'fba': False,
            },
            {
                'asin': '0811867188',
                'country': 'us',
                'condition': 'Used',
                'subcondition': 'VeryGood',
                'product_price': 17.64,
                'shipping_price': 0,
                'price': 17.64,
                'currency': 'USD',
                'shipping_time': {
                    'min': 0,
                    'max': 2
                },
                'rating': {
                    'min': 80,
                    'max': 89
                },
                'feedback': 30333,
                'domestic': True,
                'fba': False,
            },
            {
                'asin': '0811867188',
                'country': 'us',
                'condition': 'Used',
                'subcondition': 'Good',
                'product_price': 17.80,
                'shipping_price': 0,
                'price': 17.80,
                'currency': 'USD',
                'shipping_time': {
                    'min': 0,
                    'max': 2
                },
                'rating': {
                    'min': 90,
                    'max': 94
                },
                'feedback': 92,
                'domestic': True,
                'fba': True,
            },
        ],
        '3836554410': [
            {
                'asin': '3836554410',
                'country': 'us',
                'condition': 'New',
                'subcondition': 'New',
                'product_price': 18.30,
                'shipping_price': 0,
                'price': 18.30,
                'currency': 'USD',
                'shipping_time': {
                    'min': 0,
                    'max': 2
                },
                'rating': {
                    'min': 98,
                    'max': 100
                },
                'feedback': 112484,
                'domestic': True,
                'fba': True,
            },
            {
                'asin': '3836554410',
                'country': 'us',
                'condition': 'New',
                'subcondition': 'New',
                'product_price': 16.09,
                'shipping_price': 3.99,
                'price': 20.08,
                'currency': 'USD',
                'shipping_time': {
                    'min': 0,
                    'max': 2
                },
                'rating': {
                    'min': 80,
                    'max': 89
                },
                'feedback': 191443,
                'domestic': True,
                'fba': False,
            },
            {
                'asin': '3836554410',
                'country': 'us',
                'condition': 'Used',
                'subcondition': 'Mint',
                'product_price': 16.34,
                'shipping_price': 3.99,
                'price': 20.33,
                'currency': 'USD',
                'shipping_time': {
                    'min': 0,
                    'max': 2
                },
                'rating': {
                    'min': 80,
                    'max': 89
                },
                'feedback': 191443,
                'domestic': True,
                'fba': False,
            },
            {
                'asin': '3836554410',
                'country': 'us',
                'condition': 'Used',
                'subcondition': 'Good',
                'product_price': 16.35,
                'shipping_price': 3.99,
                'price': 20.34,
                'currency': 'USD',
                'shipping_time': {
                    'min': 0,
                    'max': 2
                },
                'rating': {
                    'min': 98,
                    'max': 100
                },
                'feedback': 13948,
                'domestic': True,
                'fba': False,
            },
            {
                'asin': '3836554410',
                'country': 'us',
                'condition': 'New',
                'subcondition': 'New',
                'product_price': 20.35,
                'shipping_price': 0,
                'price': 20.35,
                'currency': 'USD',
                'shipping_time': {
                    'min': 0,
                    'max': 2
                },
                'rating': {
                    'min': 95,
                    'max': 97
                },
                'feedback': 80142,
                'domestic': True,
                'fba': False,
            },
            {
                'asin': '3836554410',
                'country': 'us',
                'condition': 'New',
                'subcondition': 'New',
                'product_price': 16.85,
                'shipping_price': 3.99,
                'price': 20.84,
                'currency': 'USD',
                'shipping_time': {
                    'min': 0,
                    'max': 2
                },
                'rating': {
                    'min': 95,
                    'max': 97
                },
                'feedback': 3023689,
                'domestic': True,
                'fba': False,
            },
            {
                'asin': '3836554410',
                'country': 'us',
                'condition': 'New',
                'subcondition': 'New',
                'product_price': 21.58,
                'shipping_price': 0,
                'price': 21.58,
                'currency': 'USD',
                'shipping_time': {
                    'min': 3,
                    'max': 7
                },
                'rating': {
                    'min': 90,
                    'max': 94
                },
                'feedback': 14159,
                'domestic': True,
                'fba': False,
            },
            {
                'asin': '3836554410',
                'country': 'us',
                'condition': 'New',
                'subcondition': 'New',
                'product_price': 21.62,
                'shipping_price': 0,
                'price': 21.62,
                'currency': 'USD',
                'shipping_time': {
                    'min': 8,
                    'max': 13
                },
                'rating': {
                    'min': 80,
                    'max': 89
                },
                'feedback': 149,
                'domestic': True,
                'fba': False,
            },
            {
                'asin': '3836554410',
                'country': 'us',
                'condition': 'New',
                'subcondition': 'New',
                'product_price': 21.68,
                'shipping_price': 0,
                'price': 21.68,
                'currency': 'USD',
                'shipping_time': {
                    'min': 3,
                    'max': 7
                },
                'rating': {
                    'min': 80,
                    'max': 89
                },
                'feedback': 36620,
                'domestic': True,
                'fba': False,
            },
            {
                'asin': '3836554410',
                'country': 'us',
                'condition': 'Used',
                'subcondition': 'VeryGood',
                'product_price': 22.79,
                'shipping_price': 0,
                'price': 22.79,
                'currency': 'USD',
                'shipping_time': {
                    'min': 0,
                    'max': 2
                },
                'rating': {
                    'min': 80,
                    'max': 89
                },
                'feedback': 5156,
                'domestic': True,
                'fba': False,
            },
            {
                'asin': '3836554410',
                'country': 'us',
                'condition': 'New',
                'subcondition': 'New',
                'product_price': 19.49,
                'shipping_price': 3.99,
                'price': 23.48,
                'currency': 'USD',
                'shipping_time': {
                    'min': 0,
                    'max': 2
                },
                'rating': {
                    'min': 60,
                    'max': 69
                },
                'feedback': 3,
                'domestic': True,
                'fba': False,
            },
            {
                'asin': '3836554410',
                'country': 'us',
                'condition': 'New',
                'subcondition': 'New',
                'product_price': 20.00,
                'shipping_price': 3.99,
                'price': 23.99,
                'currency': 'USD',
                'shipping_time': {
                    'min': 0,
                    'max': 2
                },
                'rating': {
                    'min': 98,
                    'max': 100
                },
                'feedback': 58962,
                'domestic': True,
                'fba': False,
            },
        ],
        '1579656471': [
            {
                'asin': '1579656471',
                'country': 'us',
                'condition': 'Used',
                'subcondition': 'VeryGood',
                'product_price': 39.91,
                'shipping_price': 3.99,
                'price': 43.90,
                'currency': 'USD',
                'shipping_time': {
                    'min': 0,
                    'max': 2
                },
                'rating': {
                    'min': 95,
                    'max': 97
                },
                'feedback': 153142,
                'domestic': True,
                'fba': False,
            },
            {
                'asin': '1579656471',
                'country': 'us',
                'condition': 'Used',
                'subcondition': 'Good',
                'product_price': 40.64,
                'shipping_price': 3.99,
                'price': 44.63,
                'currency': 'USD',
                'shipping_time': {
                    'min': 0,
                    'max': 2
                },
                'rating': {
                    'min': 95,
                    'max': 97
                },
                'feedback': 29382,
                'domestic': True,
                'fba': False,
            },
            {
                'asin': '1579656471',
                'country': 'us',
                'condition': 'New',
                'subcondition': 'New',
                'product_price': 40.72,
                'shipping_price': 3.99,
                'price': 44.71,
                'currency': 'USD',
                'shipping_time': {
                    'min': 0,
                    'max': 2
                },
                'rating': {
                    'min': 95,
                    'max': 97
                },
                'feedback': 16121,
                'domestic': True,
                'fba': False,
            },
            {
                'asin': '1579656471',
                'country': 'us',
                'condition': 'New',
                'subcondition': 'New',
                'product_price': 44.72,
                'shipping_price': 0,
                'price': 44.72,
                'currency': 'USD',
                'shipping_time': {
                    'min': 0,
                    'max': 2
                },
                'rating': {
                    'min': 98,
                    'max': 100
                },
                'feedback': 1549,
                'domestic': True,
                'fba': True,
            },
            {
                'asin': '1579656471',
                'country': 'us',
                'condition': 'New',
                'subcondition': 'New',
                'product_price': 43.08,
                'shipping_price': 3.99,
                'price': 47.07,
                'currency': 'USD',
                'shipping_time': {
                    'min': 0,
                    'max': 2
                },
                'rating': {
                    'min': 98,
                    'max': 100
                },
                'feedback': 3,
                'domestic': True,
                'fba': False,
            },
            {
                'asin': '1579656471',
                'country': 'us',
                'condition': 'Used',
                'subcondition': 'Mint',
                'product_price': 45.04,
                'shipping_price': 3.99,
                'price': 49.03,
                'currency': 'USD',
                'shipping_time': {
                    'min': 0,
                    'max': 2
                },
                'rating': {
                    'min': 80,
                    'max': 89
                },
                'feedback': 65775,
                'domestic': True,
                'fba': False,
            },
            {
                'asin': '1579656471',
                'country': 'us',
                'condition': 'Used',
                'subcondition': 'Mint',
                'product_price': 45.05,
                'shipping_price': 3.99,
                'price': 49.04,
                'currency': 'USD',
                'shipping_time': {
                    'min': 3,
                    'max': 7
                },
                'rating': {
                    'min': 80,
                    'max': 89
                },
                'feedback': 219068,
                'domestic': True,
                'fba': False,
            },
            {
                'asin': '1579656471',
                'country': 'us',
                'condition': 'New',
                'subcondition': 'New',
                'product_price': 45.30,
                'shipping_price': 3.99,
                'price': 49.29,
                'currency': 'USD',
                'shipping_time': {
                    'min': 0,
                    'max': 2
                },
                'rating': {
                    'min': 80,
                    'max': 89
                },
                'feedback': 65775,
                'domestic': True,
                'fba': False,
            },
            {
                'asin': '1579656471',
                'country': 'us',
                'condition': 'New',
                'subcondition': 'New',
                'product_price': 45.31,
                'shipping_price': 3.99,
                'price': 49.30,
                'currency': 'USD',
                'shipping_time': {
                    'min': 3,
                    'max': 7
                },
                'rating': {
                    'min': 80,
                    'max': 89
                },
                'feedback': 219068,
                'domestic': True,
                'fba': False,
            },
            {
                'asin': '1579656471',
                'country': 'us',
                'condition': 'New',
                'subcondition': 'New',
                'product_price': 53.57,
                'shipping_price': 0,
                'price': 53.57,
                'currency': 'USD',
                'shipping_time': {
                    'min': 3,
                    'max': 7
                },
                'rating': {
                    'min': 90,
                    'max': 94
                },
                'feedback': 492983,
                'domestic': True,
                'fba': False,
            },
            {
                'asin': '1579656471',
                'country': 'us',
                'condition': 'Used',
                'subcondition': 'VeryGood',
                'product_price': 51.43,
                'shipping_price': 3.99,
                'price': 55.42,
                'currency': 'USD',
                'shipping_time': {
                    'min': 0,
                    'max': 2
                },
                'rating': {
                    'min': 98,
                    'max': 100
                },
                'feedback': 3,
                'domestic': True,
                'fba': False,
            },
            {
                'asin': '1579656471',
                'country': 'us',
                'condition': 'Used',
                'subcondition': 'Mint',
                'product_price': 55.55,
                'shipping_price': 0,
                'price': 55.55,
                'currency': 'USD',
                'shipping_time': {
                    'min': 0,
                    'max': 2
                },
                'rating': {
                    'min': 95,
                    'max': 97
                },
                'feedback': 8731,
                'domestic': True,
                'fba': False,
            },
        ],
        '1941701213': [
            {
                'asin': '1941701213',
                'country': 'us',
                'condition': 'Collectible',
                'subcondition': 'VeryGood',
                'product_price': 34.99,
                'shipping_price': 0,
                'price': 34.99,
                'currency': 'USD',
                'shipping_time': {
                    'min': 0,
                    'max': 2
                },
                'rating': {
                    'min': 90,
                    'max': 94
                },
                'feedback': 1016482,
                'domestic': True,
                'fba': False,
            },
            {
                'asin': '1941701213',
                'country': 'us',
                'condition': 'New',
                'subcondition': 'New',
                'product_price': 37.40,
                'shipping_price': 0,
                'price': 37.40,
                'currency': 'USD',
                'shipping_time': {
                    'min': 0,
                    'max': 2
                },
                'rating': {
                    'min': 98,
                    'max': 100
                },
                'feedback': 165140,
                'domestic': True,
                'fba': True,
            },
            {
                'asin': '1941701213',
                'country': 'us',
                'condition': 'Used',
                'subcondition': 'Mint',
                'product_price': 36.73,
                'shipping_price': 3.99,
                'price': 40.72,
                'currency': 'USD',
                'shipping_time': {
                    'min': 0,
                    'max': 2
                },
                'rating': {
                    'min': 80,
                    'max': 89
                },
                'feedback': 191443,
                'domestic': True,
                'fba': False,
            },
            {
                'asin': '1941701213',
                'country': 'us',
                'condition': 'Used',
                'subcondition': 'Good',
                'product_price': 36.74,
                'shipping_price': 3.99,
                'price': 40.73,
                'currency': 'USD',
                'shipping_time': {
                    'min': 0,
                    'max': 2
                },
                'rating': {
                    'min': 98,
                    'max': 100
                },
                'feedback': 318657,
                'domestic': True,
                'fba': False,
            },
            {
                'asin': '1941701213',
                'country': 'us',
                'condition': 'New',
                'subcondition': 'New',
                'product_price': 37.69,
                'shipping_price': 3.99,
                'price': 41.68,
                'currency': 'USD',
                'shipping_time': {
                    'min': 0,
                    'max': 2
                },
                'rating': {
                    'min': 80,
                    'max': 89
                },
                'feedback': 191443,
                'domestic': True,
                'fba': False,
            },
            {
                'asin': '1941701213',
                'country': 'us',
                'condition': 'New',
                'subcondition': 'New',
                'product_price': 41.69,
                'shipping_price': 0,
                'price': 41.69,
                'currency': 'USD',
                'shipping_time': {
                    'min': 0,
                    'max': 2
                },
                'rating': {
                    'min': 95,
                    'max': 97
                },
                'feedback': 80142,
                'domestic': True,
                'fba': False,
            },
            {
                'asin': '1941701213',
                'country': 'us',
                'condition': 'Used',
                'subcondition': 'Mint',
                'product_price': 45.20,
                'shipping_price': 0,
                'price': 45.20,
                'currency': 'USD',
                'shipping_time': {
                    'min': 0,
                    'max': 2
                },
                'rating': {
                    'min': 95,
                    'max': 97
                },
                'feedback': 8731,
                'domestic': True,
                'fba': False,
            },
            {
                'asin': '1941701213',
                'country': 'us',
                'condition': 'Used',
                'subcondition': 'Mint',
                'product_price': 43.71,
                'shipping_price': 3.99,
                'price': 47.70,
                'currency': 'USD',
                'shipping_time': {
                    'min': 3,
                    'max': 7
                },
                'rating': {
                    'min': 80,
                    'max': 89
                },
                'feedback': 33343,
                'domestic': True,
                'fba': False,
            },
            {
                'asin': '1941701213',
                'country': 'us',
                'condition': 'New',
                'subcondition': 'New',
                'product_price': 47.81,
                'shipping_price': 0,
                'price': 47.81,
                'currency': 'USD',
                'shipping_time': {
                    'min': 8,
                    'max': 13
                },
                'rating': {
                    'min': 90,
                    'max': 94
                },
                'feedback': 14923,
                'domestic': False,
                'fba': False,
            },
            {
                'asin': '1941701213',
                'country': 'us',
                'condition': 'Used',
                'subcondition': 'Mint',
                'product_price': 47.86,
                'shipping_price': 0,
                'price': 47.86,
                'currency': 'USD',
                'shipping_time': {
                    'min': 8,
                    'max': 13
                },
                'rating': {
                    'min': 90,
                    'max': 94
                },
                'feedback': 14923,
                'domestic': False,
                'fba': False,
            },
            {
                'asin': '1941701213',
                'country': 'us',
                'condition': 'New',
                'subcondition': 'New',
                'product_price': 44.60,
                'shipping_price': 3.99,
                'price': 48.59,
                'currency': 'USD',
                'shipping_time': {
                    'min': 3,
                    'max': 7
                },
                'rating': {
                    'min': 80,
                    'max': 89
                },
                'feedback': 33343,
                'domestic': True,
                'fba': False,
            },
            {
                'asin': '1941701213',
                'country': 'us',
                'condition': 'Used',
                'subcondition': 'Good',
                'product_price': 49.11,
                'shipping_price': 0,
                'price': 49.11,
                'currency': 'USD',
                'shipping_time': {
                    'min': 0,
                    'max': 2
                },
                'rating': {
                    'min': 90,
                    'max': 94
                },
                'feedback': 4513,
                'domestic': True,
                'fba': False,
            },
            {
                'asin': '1941701213',
                'country': 'us',
                'condition': 'New',
                'subcondition': 'New',
                'product_price': 49.15,
                'shipping_price': 0,
                'price': 49.15,
                'currency': 'USD',
                'shipping_time': {
                    'min': 14,
                    'max': 180
                },
                'rating': {
                    'min': 90,
                    'max': 94
                },
                'feedback': 14159,
                'domestic': True,
                'fba': False,
            },
            {
                'asin': '1941701213',
                'country': 'us',
                'condition': 'New',
                'subcondition': 'New',
                'product_price': 42.69,
                'shipping_price': 6.49,
                'price': 49.18,
                'currency': 'USD',
                'shipping_time': {
                    'min': 3,
                    'max': 7
                },
                'rating': {
                    'min': 95,
                    'max': 97
                },
                'feedback': 399987,
                'domestic': True,
                'fba': False,
            },
        ],
        '0811877566': [
            {
                'asin': '0811877566',
                'country': 'us',
                'condition': 'Used',
                'subcondition': 'Good',
                'product_price': 14.10,
                'shipping_price': 3.99,
                'price': 18.09,
                'currency': 'USD',
                'shipping_time': {
                    'min': 0,
                    'max': 2
                },
                'rating': {
                    'min': 98,
                    'max': 100
                },
                'feedback': 160952,
                'domestic': True,
                'fba': False,
            },
            {
                'asin': '0811877566',
                'country': 'us',
                'condition': 'Used',
                'subcondition': 'Acceptable',
                'product_price': 14.11,
                'shipping_price': 3.99,
                'price': 18.10,
                'currency': 'USD',
                'shipping_time': {
                    'min': 0,
                    'max': 2
                },
                'rating': {
                    'min': 95,
                    'max': 97
                },
                'feedback': 47682,
                'domestic': True,
                'fba': False,
            },
            {
                'asin': '0811877566',
                'country': 'us',
                'condition': 'Used',
                'subcondition': 'Good',
                'product_price': 12.25,
                'shipping_price': 5.99,
                'price': 18.24,
                'currency': 'USD',
                'shipping_time': {
                    'min': 0,
                    'max': 2
                },
                'rating': {
                    'min': 95,
                    'max': 97
                },
                'feedback': 46968,
                'domestic': False,
                'fba': False,
            },
            {
                'asin': '0811877566',
                'country': 'us',
                'condition': 'Used',
                'subcondition': 'Acceptable',
                'product_price': 15.03,
                'shipping_price': 4.55,
                'price': 19.58,
                'currency': 'USD',
                'shipping_time': {
                    'min': 0,
                    'max': 2
                },
                'rating': {
                    'min': 98,
                    'max': 100
                },
                'feedback': 152,
                'domestic': True,
                'fba': False,
            },
            {
                'asin': '0811877566',
                'country': 'us',
                'condition': 'Used',
                'subcondition': 'Good',
                'product_price': 15.99,
                'shipping_price': 3.99,
                'price': 19.98,
                'currency': 'USD',
                'shipping_time': {
                    'min': 0,
                    'max': 2
                },
                'rating': {
                    'min': 95,
                    'max': 97
                },
                'feedback': 18938,
                'domestic': True,
                'fba': False,
            },
            {
                'asin': '0811877566',
                'country': 'us',
                'condition': 'Used',
                'subcondition': 'Good',
                'product_price': 21.99,
                'shipping_price': 3.99,
                'price': 25.98,
                'currency': 'USD',
                'shipping_time': {
                    'min': 3,
                    'max': 7
                },
                'rating': {
                    'min': 80,
                    'max': 89
                },
                'feedback': 250,
                'domestic': True,
                'fba': False,
            },
            {
                'asin': '0811877566',
                'country': 'us',
                'condition': 'Used',
                'subcondition': 'Good',
                'product_price': 27.19,
                'shipping_price': 0,
                'price': 27.19,
                'currency': 'USD',
                'shipping_time': {
                    'min': 0,
                    'max': 2
                },
                'rating': {
                    'min': 90,
                    'max': 94
                },
                'feedback': 4513,
                'domestic': True,
                'fba': False,
            },
            {
                'asin': '0811877566',
                'country': 'us',
                'condition': 'Used',
                'subcondition': 'Good',
                'product_price': 27.99,
                'shipping_price': 0,
                'price': 27.99,
                'currency': 'USD',
                'shipping_time': {
                    'min': 0,
                    'max': 2
                },
                'rating': {
                    'min': 98,
                    'max': 100
                },
                'feedback': 4,
                'domestic': True,
                'fba': True,
            },
            {
                'asin': '0811877566',
                'country': 'us',
                'condition': 'Used',
                'subcondition': 'Mint',
                'product_price': 28.00,
                'shipping_price': 0,
                'price': 28.00,
                'currency': 'USD',
                'shipping_time': {
                    'min': 0,
                    'max': 2
                },
                'rating': {
                    'min': 98,
                    'max': 100
                },
                'feedback': 105,
                'domestic': True,
                'fba': True,
            },
            {
                'asin': '0811877566',
                'country': 'us',
                'condition': 'Used',
                'subcondition': 'VeryGood',
                'product_price': 28.00,
                'shipping_price': 0,
                'price': 28.00,
                'currency': 'USD',
                'shipping_time': {
                    'min': 0,
                    'max': 2
                },
                'rating': {
                    'min': 98,
                    'max': 100
                },
                'feedback': 943,
                'domestic': True,
                'fba': True,
            },
            {
                'asin': '0811877566',
                'country': 'us',
                'condition': 'New',
                'subcondition': 'New',
                'product_price': 28.51,
                'shipping_price': 0,
                'price': 28.51,
                'currency': 'USD',
                'shipping_time': {
                    'min': 0,
                    'max': 2
                },
                'rating': {
                    'min': 98,
                    'max': 100
                },
                'feedback': 140196,
                'domestic': True,
                'fba': True,
            },
            {
                'asin': '0811877566',
                'country': 'us',
                'condition': 'Used',
                'subcondition': 'VeryGood',
                'product_price': 24.13,
                'shipping_price': 4.49,
                'price': 28.62,
                'currency': 'USD',
                'shipping_time': {
                    'min': 0,
                    'max': 2
                },
                'rating': {
                    'min': 80,
                    'max': 89
                },
                'feedback': 69671,
                'domestic': True,
                'fba': False,
            },
            {
                'asin': '0811877566',
                'country': 'us',
                'condition': 'Used',
                'subcondition': 'Good',
                'product_price': 29.93,
                'shipping_price': 0,
                'price': 29.93,
                'currency': 'USD',
                'shipping_time': {
                    'min': 0,
                    'max': 2
                },
                'rating': {
                    'min': 80,
                    'max': 89
                },
                'feedback': 97,
                'domestic': True,
                'fba': True,
            },
        ],
        '0023632909': [
            {
                'asin': '0023632909',
                'country': 'us',
                'condition': 'New',
                'subcondition': 'New',
                'product_price': 73.29,
                'shipping_price': 0,
                'price': 73.29,
                'currency': 'USD',
                'shipping_time': {
                    'min': 14,
                    'max': 180
                },
                'rating': {
                    'min': 95,
                    'max': 97
                },
                'feedback': 11461,
                'domestic': True,
                'fba': False
            },
        ],
        '0310445132': [
            {
                'asin': '0310445132',
                'country': 'us',
                'condition': 'Used',
                'subcondition': 'VeryGood',
                'product_price': 19.99,
                'shipping_price': 3.99,
                'price': 23.98,
                'currency': 'USD',
                'shipping_time': {
                    'min': 0,
                    'max': 2
                },
                'rating': {
                    'min': 95,
                    'max': 97
                },
                'feedback': 2581,
                'domestic': True,
                'fba': False
            },
            {
                'asin': '0310445132',
                'country': 'us',
                'condition': 'Used',
                'subcondition': 'Mint',
                'product_price': 20.00,
                'shipping_price': 3.99,
                'price': 23.99,
                'currency': 'USD',
                'shipping_time': {
                    'min': 0,
                    'max': 2
                },
                'rating': {
                    'min': 98,
                    'max': 100
                },
                'feedback': 346,
                'domestic': True,
                'fba': False
            },
            {
                'asin': '0310445132',
                'country': 'us',
                'condition': 'Used',
                'subcondition': 'Good',
                'product_price': 20.00,
                'shipping_price': 3.99,
                'price': 23.99,
                'currency': 'USD',
                'shipping_time': {
                    'min': 0,
                    'max': 2
                },
                'rating': {
                    'min': 98,
                    'max': 100
                },
                'feedback': 20251,
                'domestic': True,
                'fba': False
            },
            {
                'asin': '0310445132',
                'country': 'us',
                'condition': 'New',
                'subcondition': 'New',
                'product_price': 24.32,
                'shipping_price': 0,
                'price': 24.32,
                'currency': 'USD',
                'shipping_time': {
                    'min': 0,
                    'max': 2
                },
                'rating': {
                    'min': 98,
                    'max': 100
                },
                'feedback': 435265,
                'domestic': True,
                'fba': True
            },
            {
                'asin': '0310445132',
                'country': 'us',
                'condition': 'New',
                'subcondition': 'New',
                'product_price': 24.32,
                'shipping_price': 0,
                'price': 24.32,
                'currency': 'USD',
                'shipping_time': {
                    'min': 0,
                    'max': 2
                },
                'rating': {
                    'min': 60,
                    'max': 69
                },
                'feedback': 82,
                'domestic': True,
                'fba': False
            },
            {
                'asin': '0310445132',
                'country': 'us',
                'condition': 'Used',
                'subcondition': 'Mint',
                'product_price': 24.32,
                'shipping_price': 3.99,
                'price': 28.31,
                'currency': 'USD',
                'shipping_time': {
                    'min': 0,
                    'max': 2
                },
                'rating': {
                    'min': 80,
                    'max': 89
                },
                'feedback': 53695,
                'domestic': True,
                'fba': False
            },
            {
                'asin': '0310445132',
                'country': 'us',
                'condition': 'New',
                'subcondition': 'New',
                'product_price': 24.32,
                'shipping_price': 3.99,
                'price': 28.31,
                'currency': 'USD',
                'shipping_time': {
                    'min': 0,
                    'max': 2
                },
                'rating': {
                    'min': 80,
                    'max': 89
                },
                'feedback': 53695,
                'domestic': True,
                'fba': False
            }
        ]
    }

    yield target_offers

@pytest.fixture(scope='session')
def target_buy_box_offers():
    target_offers = {
        '0811867188': [
            {
                'asin': '0811867188',
                'country': 'us',
                'condition': 'Used',
                'subcondition': 'Good',
                'currency': 'USD',
                'product_price': 17.17,
                'shipping_price': 0,
                'price': 17.17,
                'belongs_to_requester': False
            },
            {
                'asin': '0811867188',
                'country': 'us',
                'condition': 'New',
                'subcondition': 'New',
                'currency': 'USD',
                'product_price': 24.88,
                'shipping_price': 0,
                'price': 24.88,
                'belongs_to_requester': False
            },
        ],
        '3836554410': [
            {
                'asin': '3836554410',
                'country': 'us',
                'condition': 'Used',
                'subcondition': 'Good',
                'currency': 'USD',
                'product_price': 16.35,
                'shipping_price': 3.99,
                'price': 20.34,
                'belongs_to_requester': False
            },
            {
                'asin': '3836554410',
                'country': 'us',
                'condition': 'New',
                'subcondition': 'New',
                'currency': 'USD',
                'product_price': 18.30,
                'shipping_price': 0,
                'price': 18.30,
                'belongs_to_requester': False
            },
        ],
        '1579656471': [
            {
                'asin': '1579656471',
                'country': 'us',
                'condition': 'Used',
                'subcondition': 'Acceptable',
                'currency': 'USD',
                'product_price': 43.90,
                'shipping_price': 0,
                'price': 43.90,
                'belongs_to_requester': False
            },
            {
                'asin': '1579656471',
                'country': 'us',
                'condition': 'New',
                'subcondition': 'New',
                'currency': 'USD',
                'product_price': 44.72,
                'shipping_price': 0,
                'price': 44.72,
                'belongs_to_requester': False
            },
        ],
        '1941701213': [
            {
                'asin': '1941701213',
                'country': 'us',
                'condition': 'Used',
                'subcondition': 'Good',
                'currency': 'USD',
                'product_price': 36.74,
                'shipping_price': 3.99,
                'price': 40.73,
                'belongs_to_requester': False
            },
            {
                'asin': '1941701213',
                'country': 'us',
                'condition': 'New',
                'subcondition': 'New',
                'currency': 'USD',
                'product_price': 37.40,
                'shipping_price': 0,
                'price': 37.40,
                'belongs_to_requester': False
            },
        ],
        '0811877566': [
            {
                'asin': '0811877566',
                'country': 'us',
                'condition': 'Used',
                'subcondition': 'Good',
                'currency': 'USD',
                'product_price': 27.99,
                'shipping_price': 0,
                'price': 27.99,
                'belongs_to_requester': False
            },
            {
                'asin': '0811877566',
                'country': 'us',
                'condition': 'New',
                'subcondition': 'New',
                'currency': 'USD',
                'product_price': 28.51,
                'shipping_price': 0,
                'price': 28.51,
                'belongs_to_requester': False
            },
        ],
        '0023632909': [
            {
                'asin': '0023632909',
                'country': 'us',
                'condition': 'Used',
                'subcondition': 'Good',
                'currency': 'USD',
                'product_price': 5.86,
                'shipping_price': 0,
                'price': 5.86,
                'belongs_to_requester': False
            }
        ],
        '0310445132': [
            {
                'asin': '0310445132',
                'country': 'us',
                'condition': 'New',
                'subcondition': 'New',
                'currency': 'USD',
                'product_price': 24.32,
                'shipping_price': 0,
                'price': 24.32,
                'belongs_to_requester': False
            },
            {
                'asin': '0310445132',
                'country': 'us',
                'condition': 'Used',
                'subcondition': 'Good',
                'currency': 'USD',
                'product_price': 38.10,
                'shipping_price': 0,
                'price': 38.10,
                'belongs_to_requester': False
            },
        ]
    }

    yield target_offers

@pytest.fixture(scope='session')
def target_filtered_lowest_offer_listing_offers():
    target_offers = {
        '0811867188': {
            'asin': '0811867188',
            'country': 'us',
            'condition': 'Used',
            'subcondition': 'Good',
            'product_price': 6.36,
            'shipping_price': 3.94,
            'price': 10.30,
            'currency': 'USD',
            'shipping_time': {
                'min': 0,
                'max': 2
            },
            'rating': {
                'min': 95,
                'max': 97
            },
            'feedback': 68573,
            'domestic': True,
            'fba': False
        },
        '3836554410': {
            'asin': '3836554410',
            'country': 'us',
            'condition': 'New',
            'subcondition': 'New',
            'product_price': 18.30,
            'shipping_price': 0,
            'price': 18.30,
            'currency': 'USD',
            'shipping_time': {
                'min': 0,
                'max': 2
            },
            'rating': {
                'min': 98,
                'max': 100
            },
            'feedback': 112484,
            'domestic': True,
            'fba': True,
        },
        '1579656471': {
            'asin': '1579656471',
            'country': 'us',
            'condition': 'Used',
            'subcondition': 'VeryGood',
            'product_price': 39.91,
            'shipping_price': 3.99,
            'price': 43.90,
            'currency': 'USD',
            'shipping_time': {
                'min': 0,
                'max': 2
            },
            'rating': {
                'min': 95,
                'max': 97
            },
            'feedback': 153142,
            'domestic': True,
            'fba': False,
        },
        '1941701213': {
            'asin': '1941701213',
            'country': 'us',
            'condition': 'Collectible',
            'subcondition': 'VeryGood',
            'product_price': 34.99,
            'shipping_price': 0,
            'price': 34.99,
            'currency': 'USD',
            'shipping_time': {
                'min': 0,
                'max': 2
            },
            'rating': {
                'min': 90,
                'max': 94
            },
            'feedback': 1016482,
            'domestic': True,
            'fba': False,
        },
        '0811877566': {
            'asin': '0811877566',
            'country': 'us',
            'condition': 'Used',
            'subcondition': 'Good',
            'product_price': 14.10,
            'shipping_price': 3.99,
            'price': 18.09,
            'currency': 'USD',
            'shipping_time': {
                'min': 0,
                'max': 2
            },
            'rating': {
                'min': 98,
                'max': 100
            },
            'feedback': 160952,
            'domestic': True,
            'fba': False,
        },
        '0023632909': None,
        '0310445132': {
            'asin': '0310445132',
            'country': 'us',
            'condition': 'Used',
            'subcondition': 'VeryGood',
            'product_price': 19.99,
            'shipping_price': 3.99,
            'price': 23.98,
            'currency': 'USD',
            'shipping_time': {
                'min': 0,
                'max': 2
            },
            'rating': {
                'min': 95,
                'max': 97
            },
            'feedback': 2581,
            'domestic': True,
            'fba': False
        },
        '0310445131': None
    }

    yield target_offers

@pytest.fixture(scope='session')
def target_filtered_lol_offers_with_count():
    target_offers = {
        '0811867188': {
            'asin': '0811867188',
            'country': 'us',
            'condition': 'Used',
            'subcondition': 'Good',
            'product_price': 7.56,
            'shipping_price': 3.97,
            'price': 11.53,
            'currency': 'USD',
            'shipping_time': {
                'min': 0,
                'max': 2
            },
            'rating': {
                'min': 95,
                'max': 97
            },
            'feedback': 68573,
            'domestic': True,
            'fba': False
        },
        '3836554410': {
            'asin': '3836554410',
            'country': 'us',
            'condition': 'New',
            'subcondition': 'New',
            'product_price': 18.33,
            'shipping_price': 1.33,
            'price': 19.66,
            'currency': 'USD',
            'shipping_time': {
                'min': 0,
                'max': 2
            },
            'rating': {
                'min': 98,
                'max': 100
            },
            'feedback': 112484,
            'domestic': True,
            'fba': True,
        },
        '1579656471': {
            'asin': '1579656471',
            'country': 'us',
            'condition': 'Used',
            'subcondition': 'VeryGood',
            'product_price': 40.42,
            'shipping_price': 3.99,
            'price': 44.41,
            'currency': 'USD',
            'shipping_time': {
                'min': 0,
                'max': 2
            },
            'rating': {
                'min': 95,
                'max': 97
            },
            'feedback': 153142,
            'domestic': True,
            'fba': False,
        },
        '1941701213': {
            'asin': '1941701213',
            'country': 'us',
            'condition': 'Collectible',
            'subcondition': 'VeryGood',
            'product_price': 36.38,
            'shipping_price': 1.33,
            'price': 37.71,
            'currency': 'USD',
            'shipping_time': {
                'min': 0,
                'max': 2
            },
            'rating': {
                'min': 90,
                'max': 94
            },
            'feedback': 1016482,
            'domestic': True,
            'fba': False,
        },
        '0811877566': {
            'asin': '0811877566',
            'country': 'us',
            'condition': 'Used',
            'subcondition': 'Good',
            'product_price': 19.09,
            'shipping_price': 2.66,
            'price': 21.75,
            'currency': 'USD',
            'shipping_time': {
                'min': 0,
                'max': 2
            },
            'rating': {
                'min': 98,
                'max': 100
            },
            'feedback': 160952,
            'domestic': True,
            'fba': False,
        },
        '0023632909': None,
        '0310445132': {
            'asin': '0310445132',
            'country': 'us',
            'condition': 'Used',
            'subcondition': 'VeryGood',
            'product_price': 20.00,
            'shipping_price': 3.99,
            'price': 23.99,
            'currency': 'USD',
            'shipping_time': {
                'min': 0,
                'max': 2
            },
            'rating': {
                'min': 95,
                'max': 97
            },
            'feedback': 2581,
            'domestic': True,
            'fba': False
        },
        '0310445131': None
    }

    yield target_offers

@pytest.fixture(scope='session')
def target_filtered_lol_offers_with_strategy():
    target_offers = {
        '0811867188': {
            'asin': '0811867188',
            'country': 'us',
            'condition': 'Used',
            'subcondition': 'Good',
            'product_price': 6.36,
            'shipping_price': 3.94,
            'price': 10.30,
            'currency': 'USD',
            'shipping_time': {
                'min': 0,
                'max': 2
            },
            'rating': {
                'min': 95,
                'max': 97
            },
            'feedback': 68573,
            'domestic': True,
            'fba': False,
        },
        '3836554410': {
            'asin': '3836554410',
            'country': 'us',
            'condition': 'Used',
            'subcondition': 'Good',
            'product_price': 16.35,
            'shipping_price': 3.99,
            'price': 20.34,
            'currency': 'USD',
            'shipping_time': {
                'min': 0,
                'max': 2
            },
            'rating': {
                'min': 98,
                'max': 100
            },
            'feedback': 13948,
            'domestic': True,
            'fba': False,
        },
        '1579656471': {
            'asin': '1579656471',
            'country': 'us',
            'condition': 'Used',
            'subcondition': 'Good',
            'product_price': 40.64,
            'shipping_price': 3.99,
            'price': 44.63,
            'currency': 'USD',
            'shipping_time': {
                'min': 0,
                'max': 2
            },
            'rating': {
                'min': 95,
                'max': 97
            },
            'feedback': 29382,
            'domestic': True,
            'fba': False,
        },
        '1941701213': {
            'asin': '1941701213',
            'country': 'us',
            'condition': 'Used',
            'subcondition': 'Good',
            'product_price': 36.74,
            'shipping_price': 3.99,
            'price': 40.73,
            'currency': 'USD',
            'shipping_time': {
                'min': 0,
                'max': 2
            },
            'rating': {
                'min': 98,
                'max': 100
            },
            'feedback': 318657,
            'domestic': True,
            'fba': False,
        },
        '0811877566': {
            'asin': '0811877566',
            'country': 'us',
            'condition': 'Used',
            'subcondition': 'Good',
            'product_price': 14.10,
            'shipping_price': 3.99,
            'price': 18.09,
            'currency': 'USD',
            'shipping_time': {
                'min': 0,
                'max': 2
            },
            'rating': {
                'min': 98,
                'max': 100
            },
            'feedback': 160952,
            'domestic': True,
            'fba': False,
        },
        '0023632909': None,
        '0310445132': {
            'asin': '0310445132',
            'country': 'us',
            'condition': 'Used',
            'subcondition': 'Good',
            'product_price': 20.00,
            'shipping_price': 3.99,
            'price': 23.99,
            'currency': 'USD',
            'shipping_time': {
                'min': 0,
                'max': 2
            },
            'rating': {
                'min': 98,
                'max': 100
            },
            'feedback': 20251,
            'domestic': True,
            'fba': False
        },
        '0310445131': None
    }

    return target_offers

@pytest.fixture(scope='session')
def target_filtered_buybox_offers():
    target_offers = {
        '0811867188': {
            'asin': '0811867188',
            'country': 'us',
            'condition': 'Used',
            'subcondition': 'Good',
            'currency': 'USD',
            'product_price': 17.17,
            'shipping_price': 0,
            'price': 17.17,
            'belongs_to_requester': False
        },
        '3836554410': {
            'asin': '3836554410',
            'country': 'us',
            'condition': 'New',
            'subcondition': 'New',
            'currency': 'USD',
            'product_price': 18.3,
            'shipping_price': 0,
            'price': 18.3,
            'belongs_to_requester': False
        },
        '1579656471': {
            'asin': '1579656471',
            'country': 'us',
            'condition': 'Used',
            'subcondition': 'Acceptable',
            'currency': 'USD',
            'product_price': 43.90,
            'shipping_price': 0,
            'price': 43.90,
            'belongs_to_requester': False
        },
        '1941701213': {
            'asin': '1941701213',
            'country': 'us',
            'condition': 'New',
            'subcondition': 'New',
            'currency': 'USD',
            'product_price': 37.4,
            'shipping_price': 0,
            'price': 37.4,
            'belongs_to_requester': False
        },
        '0811877566': {
            'asin': '0811877566',
            'country': 'us',
            'condition': 'Used',
            'subcondition': 'Good',
            'currency': 'USD',
            'product_price': 27.99,
            'shipping_price': 0,
            'price': 27.99,
            'belongs_to_requester': False
        },
        '0023632909': {
            'asin': '0023632909',
            'country': 'us',
            'condition': 'Used',
            'subcondition': 'Good',
            'currency': 'USD',
            'product_price': 5.86,
            'shipping_price': 0,
            'price': 5.86,
            'belongs_to_requester': False
        },
        '0310445132': {
            'asin': '0310445132',
            'country': 'us',
            'condition': 'New',
            'subcondition': 'New',
            'currency': 'USD',
            'product_price': 24.32,
            'shipping_price': 0,
            'price': 24.32,
            'belongs_to_requester': False
        }
    }

    yield target_offers

@pytest.fixture(scope='session')
def target_sales_ranks():
    result = {
        '0811867188': {
            'asin': '0811867188',
            'sales_ranks': [
                {
                    'product_category_id': 'book_display_on_website',
                    'rank': 446768
                },
                {
                    'product_category_id': '11716',
                    'rank': 515
                },
                {
                    'product_category_id': '684260011',
                    'rank': 561
                },
                {
                    'product_category_id': '713036011',
                    'rank': 3415
                }
            ]
        },
        '3836554410': {
            'asin': '3836554410',
            'sales_ranks': [
                {
                    'product_category_id': 'book_display_on_website',
                    'rank': 63401
                },
                {
                    'product_category_id': '8947735011',
                    'rank': 51
                }
            ]
        },
        '1579656471': {
            'asin': '1579656471',
            'sales_ranks': [
                {
                    'product_category_id': 'book_display_on_website',
                    'rank': 49609
                },
                {
                    'product_category_id': '1872',
                    'rank': 13
                },
                {
                    'product_category_id': '1851',
                    'rank': 102
                },
                {
                    'product_category_id': '5397',
                    'rank': 132
                }
            ]
        },
        '1941701213': {
            'asin': '1941701213',
            'sales_ranks': [
                {
                    'product_category_id': 'book_display_on_website',
                    'rank': 78797
                },
                {
                    'product_category_id': '8947735011',
                    'rank': 71
                }
            ]
        },
        '0811877566': {
            'asin': '0811877566',
            'sales_ranks': [
                {
                    'product_category_id': 'book_display_on_website',
                    'rank': 37714
                },
                {
                    'product_category_id': '172636',
                    'rank': 29
                },
                {
                    'product_category_id': '11272',
                    'rank': 67
                },
                {
                    'product_category_id': '1865',
                    'rank': 117
                }
            ]
        },
        '0023632909': {
            'asin': '0023632909',
            'sales_ranks': [
                {
                    'product_category_id': 'book_display_on_website',
                    'rank': 2805270
                },
                {
                    'product_category_id': '13603',
                    'rank': 4018
                },
                {
                    'product_category_id': '491730',
                    'rank': 5071
                },
                {
                    'product_category_id': '13598',
                    'rank':8653
                },
            ]
        },
        '0310445132': {
            'asin': '0310445132',
            'sales_ranks': [
                {
                    'product_category_id': 'book_display_on_website',
                    'rank': 2293
                },
                {
                    'product_category_id': '12059',
                    'rank': 10
                },
                {
                    'product_category_id': '1',
                    'rank': 167
                }
            ]
        }
    }

    yield result

@pytest.fixture(scope='session')
def target_matching_products():
    return {
        'B00VSH7LAG': {
            'ItemAttributes': {
                'Binding': 'Health and Beauty',
                'Brand': 'ArtNaturals',
                'Color': '100% Jojoba (Simmondsia Chinensis)',
                'Flavor': '100% Jojoba (Simmondsia Chinensis)',
                'ItemDimensions': {
                    'Height': {
                        'Units': 'inches',
                        'value': 3
                    },
                    'Length': {
                        'Units': 'inches',
                        'value': 3
                    },
                    'Width': {
                        'Units': 'inches',
                        'value': 3
                    },
                    'Weight': {
                        'Units': 'pounds',
                        'value': 0.6
                    }
                },
                'IsAdultProduct': False,
                'Label': 'ArtNaturals',
                'Languages': [
                    {'Name': 'english', 'Type': 'Unknown'},
                    {'Name': 'spanish', 'Type': 'Unknown'},
                    {'Name': 'french', 'Type': 'Unknown'},
                    {'Name': 'german', 'Type': 'Unknown'},
                    {'Name': 'italian', 'Type': 'Unknown'},
                ],
                'ListPrice': {
                    'Amount': 48.95,
                    'CurrencyCode': 'USD'
                },
                'Manufacturer': 'ArtNaturals',
                'Model': 'Jojoba_4',
                'PackageDimensions': {
                    'Height': {
                        'Units': 'inches',
                        'value': 4.4
                    },
                    'Length': {
                        'Units': 'inches',
                        'value': 6.4
                    },
                    'Width': {
                        'Units': 'inches',
                        'value': 4.4
                    },
                    'Weight': {
                        'Units': 'pounds',
                        'value': 0.8
                    }
                },
                'PackageQuantity': 1,
                'PartNumber': 'Jojoba_4',
                'ProductGroup': 'Beauty',
                'ProductTypeName': 'BEAUTY',
                'Publisher': 'ArtNaturals',
                'Scent': '100% Jojoba (Simmondsia Chinensis)',
                'Size': '4 Fl Oz / 120ml',
                'SmallImage': {
                    'URL': 'http://ecx.images-amazon.com/images/I/41WZpSQBhnL._SL75_.jpg',
                    'Height': {
                        'Units': 'pixels',
                        'value': 75
                    },
                    'Width': {
                        'Units': 'pixels',
                        'value': 57
                    }
                },
                'Studio': 'ArtNaturals',
                'Title': 'ArtNaturals USDA Organic Jojoba Oil - (4 Fl Oz / 120ml) - 100% Pure Golden Cold Pressed Carrier Oil - Sensitive Skin, Face Hair, Nails and Cuticle - Dry Scalp Blemish and Acne Treatment'
            },
            'SalesRankings': [
                {'ProductCategoryId': 'beauty_display_on_website', 'Rank': 9002},
                {'ProductCategoryId': '7792527011', 'Rank': 46},
            ]
        },
        'B0731NM58C': {
            'ItemAttributes': {
                'Binding': 'Electronics',
                'Brand': 'Blink Home Security',
                'Color': '2 Camera Kit',
                'ItemDimensions': {
                    'Height': {
                        'Units': 'inches',
                        'value': 7.5
                    },
                    'Length': {
                        'Units': 'inches',
                        'value': 9.5
                    },
                    'Width': {
                        'Units': 'inches',
                        'value': 2.5
                    },
                    'Weight': {
                        'Units': 'pounds',
                        'value': 0.59
                    }
                },
                'IsAdultProduct': False,
                'Label': 'Blink Home Security',
                'ListPrice': {
                    'Amount': 229.99,
                    'CurrencyCode': 'USD'
                },
                'Manufacturer': 'Blink Home Security',
                'Model': 'FBA_BKIT004602',
                'PackageDimensions': {
                    'Height': {
                        'Units': 'inches',
                        'value': 2.6
                    },
                    'Length': {
                        'Units': 'inches',
                        'value': 9.7
                    },
                    'Width': {
                        'Units': 'inches',
                        'value': 7.7
                    },
                    'Weight': {
                        'Units': 'pounds',
                        'value': 1.4
                    }
                },
                'PackageQuantity': 1,
                'PartNumber': 'FBA_BKIT004602',
                'ProductGroup': 'VDO Devices',
                'ProductTypeName': 'VDO_DEVICES',
                'Publisher': 'Blink Home Security',
                'Size': 'XT 2 Camera System',
                'SmallImage': {
                    'URL': 'http://ecx.images-amazon.com/images/I/41MCh9NimSL._SL75_.jpg',
                    'Height': {
                        'Units': 'pixels',
                        'value': 75
                    },
                    'Width': {
                        'Units': 'pixels',
                        'value': 75
                    }
                },
                'Studio': 'Blink Home Security',
                'Title': 'Blink XT Home Security Camera System with Motion Detection, Wall Mount, HD Video, 2-Year Battery Life and Cloud Storage Included - 2 Camera Kit'
            },
            'SalesRankings': [
                {'ProductCategoryId': 'vdo_devices_display_on_website', 'Rank': 2},
                {'ProductCategoryId': '898400', 'Rank': 3},
            ]
        },
        'B007VBXB48': {
            'ItemAttributes': {
                'Binding': 'Office Product',
                'Brand': 'Scotch',
                'Color': 'Clear',
                'ItemDimensions': {
                    'Height': {
                        'Units': 'inches',
                        'value': 11.4
                    },
                    'Length': {
                        'Units': 'inches',
                        'value': 0.75
                    },
                    'Width': {
                        'Units': 'inches',
                        'value': 8.9
                    },
                    'Weight': {
                        'Units': 'pounds',
                        'value': 2.92
                    }
                },
                'Label': 'Scotch',
                'ListPrice': {
                    'Amount': 24.68,
                    'CurrencyCode': 'USD'
                },
                'Manufacturer': 'Scotch',
                'ManufacturerMinimumAge': {
                    'Units': 'months',
                    'value': 120.0
                },
                'MaterialType': 'Laminate',
                'Model': 'TP3854-100',
                'NumberOfItems': 1,
                'PackageDimensions': {
                    'Height': {
                        'Units': 'inches',
                        'value': 0.8
                    },
                    'Length': {
                        'Units': 'inches',
                        'value': 11.7
                    },
                    'Width': {
                        'Units': 'inches',
                        'value': 9.25
                    },
                    'Weight': {
                        'Units': 'pounds',
                        'value': 3.0
                    }
                },
                'PackageQuantity': 1,
                'PartNumber': 'TP3854-100',
                'ProductGroup': 'Office Product',
                'ProductTypeName': 'OFFICE_PRODUCTS',
                'PublicationDate': '2012-04-10',
                'Publisher': 'Scotch',
                'ReleaseDate': '2018-08-01',
                'Size': '100-Pack',
                'SmallImage': {
                    'URL': 'http://ecx.images-amazon.com/images/I/41J-2Qx73EL._SL75_.jpg',
                    'Height': {
                        'Units': 'pixels',
                        'value': 75
                    },
                    'Width': {
                        'Units': 'pixels',
                        'value': 56
                    }
                },
                'Studio': 'Scotch',
                'Title': 'Scotch Thermal Laminating Pouches, 8.9 x 11.4 -Inches, 3 mil thick, 100-Pack (TP3854-100)',
                'Warranty': 'NA'
            },
            'SalesRankings': [
                {'ProductCategoryId': 'office_product_display_on_website', 'Rank': 4},
                {'ProductCategoryId': '300341', 'Rank': 1},
            ]
        },
        'B07F2GWNRV': {
            'ItemAttributes': {
                'Binding': 'Misc.',
                'Brand': 'JASTIND',
                'Label': 'JASTIND',
                'Manufacturer': 'JASTIND',
                'Model': '5824090528',
                'PackageDimensions': {
                    'Height': {
                        'Units': 'inches',
                        'value': 1.7
                    },
                    'Length': {
                        'Units': 'inches',
                        'value': 10.7
                    },
                    'Width': {
                        'Units': 'inches',
                        'value': 2.7
                    },
                    'Weight': {
                        'Units': 'pounds',
                        'value': 0.35
                    }
                },
                'PackageQuantity': 1,
                'PartNumber': 'JTCVT-01B',
                'ProductGroup': 'Automotive Parts and Accessories',
                'ProductTypeName': 'AUTO_ACCESSORY',
                'Publisher': 'JASTIND',
                'Size': 'White Backlight',
                'SmallImage': {
                    'URL': 'http://ecx.images-amazon.com/images/I/51PcA%2ByYxPL._SL75_.jpg',
                    'Height': {
                        'Units': 'pixels',
                        'value': 75
                    },
                    'Width': {
                        'Units': 'pixels',
                        'value': 75
                    }
                },
                'Studio': 'JASTIND',
                'Title': 'JASTIND Heavy Duty 3-48V Digital LCD Display Circuit Tester with 140 Inch Extended Spring Wire,Car Truck Vehicles Low Voltage Tester,Automotive Test Light with Stainless Probe'
            },
            'SalesRankings': [
                {'ProductCategoryId': 'automotive_display_on_website', 'Rank': 4246},
                {'ProductCategoryId': '15707391', 'Rank': 7},
            ]
        },
        'B00FMWWN6U': {
            'ItemAttributes': {
                'Binding': 'Health and Beauty',
                'Brand': 'Pampers',
                'Color': 'Multi',
                'Department': 'baby-boys',
                'ItemDimensions': {
                    'Height': {
                        'Units': 'inches',
                        'value': 11.88
                    },
                    'Length': {
                        'Units': 'inches',
                        'value': 7.94
                    },
                    'Width': {
                        'Units': 'inches',
                        'value': 9.31
                    },
                    'Weight': {
                        'Units': 'pounds',
                        'value': 11.26
                    }
                },
                'IsAdultProduct': False,
                'Label': 'Procter & Gamble - Pampers',
                'ListPrice': {
                    'Amount': 19.99,
                    'CurrencyCode': 'USD'
                },
                'Manufacturer': 'Procter & Gamble - Pampers',
                'ManufacturerMaximumAge': {
                    'Units': 'months',
                    'value': 100.0
                },
                'ManufacturerMinimumAge': {
                    'Units': 'months',
                    'value': 0.0
                },
                'Model': '00037000885290',
                'NumberOfItems': 1,
                'PackageDimensions': {
                    'Height': {
                        'Units': 'inches',
                        'value': 8.0
                    },
                    'Length': {
                        'Units': 'inches',
                        'value': 12.0
                    },
                    'Width': {
                        'Units': 'inches',
                        'value': 9.0
                    },
                    'Weight': {
                        'Units': 'pounds',
                        'value': 11.5
                    }
                },
                'PackageQuantity': 1,
                'PartNumber': '00037000885290',
                'ProductGroup': 'Baby Product',
                'ProductTypeName': 'HEALTH_PERSONAL_CARE',
                'PublicationDate': '2016-05-30',
                'Publisher': 'Procter & Gamble - Pampers',
                'ReleaseDate': '2016-03-30',
                'Size': '576 Count',
                'SmallImage': {
                    'URL': 'http://ecx.images-amazon.com/images/I/41ZqjiuREdL._SL75_.jpg',
                    'Height': {
                        'Units': 'pixels',
                        'value': 75
                    },
                    'Width': {
                        'Units': 'pixels',
                        'value': 75
                    }
                },
                'Studio': 'Procter & Gamble - Pampers',
                'Title': 'Pampers Sensitive Water-Based Baby Diaper Wipes, 9 Refill Packs for Dispenser Tub - Hypoallergenic and Unscented - 576 Count'
            },
            'SalesRankings': [
                {'ProductCategoryId': 'baby_product_display_on_website', 'Rank': 1},
                {'ProductCategoryId': '677974011', 'Rank': 1},
            ]
        },
        '0385376715': {
            'ItemAttributes': {
                'Author': 'Martin, Emily Winfield',
                'Binding': 'Hardcover',
                'Brand': 'Random House Books for Young Readers',
                'Edition': '1',
                'ItemDimensions': {
                    'Height': {
                        'Units': 'inches',
                        'value': 10.31
                    },
                    'Length': {
                        'Units': 'inches',
                        'value': 9.89
                    },
                    'Width': {
                        'Units': 'inches',
                        'value': 0.38
                    },
                    'Weight': {
                        'Units': 'pounds',
                        'value': 0.95
                    }
                },
                'Label': 'Random House Books for Young Readers',
                'Languages': [
                    {'Name': 'english', 'Type': 'Published'},
                    {'Name': 'english', 'Type': 'Original Language'},
                    {'Name': 'english', 'Type': 'Unknown'}
                ],
                'ListPrice': {
                    'Amount': 17.99,
                    'CurrencyCode': 'USD'
                },
                'Manufacturer': 'Random House Books for Young Readers',
                'NumberOfItems': 1,
                'NumberOfPages': 36,
                'PackageDimensions': {
                    'Height': {
                        'Units': 'inches',
                        'value': 0.05
                    },
                    'Length': {
                        'Units': 'inches',
                        'value': 10.2
                    },
                    'Width': {
                        'Units': 'inches',
                        'value': 9.8
                    },
                    'Weight': {
                        'Units': 'pounds',
                        'value': 0.95
                    }
                },
                'PackageQuantity': 1,
                'PartNumber': '9780385376716',
                'ProductGroup': 'Book',
                'ProductTypeName': 'ABIS_BOOK',
                'PublicationDate': '2015-08-25',
                'Publisher': 'Random House Books for Young Readers',
                'ReleaseDate': '2015-08-25',
                'SmallImage': {
                    'URL': 'http://ecx.images-amazon.com/images/I/51gEY86ijML._SL75_.jpg',
                    'Height': {
                        'Units': 'pixels',
                        'value': 75
                    },
                    'Width': {
                        'Units': 'pixels',
                        'value': 71
                    }
                },
                'Studio': 'Random House Books for Young Readers',
                'Title': 'The Wonderful Things You Will Be'
            },
            'SalesRankings': [
                {'ProductCategoryId': 'book_display_on_website', 'Rank': 8},
                {'ProductCategoryId': '3061', 'Rank': 1},
                {'ProductCategoryId': '3059', 'Rank': 1},
                {'ProductCategoryId': '3012', 'Rank': 1},
            ]
        },
        'B07BQNDXCS': {
            'ItemAttributes': {
                'Artist': 'Ludwig Goransson',
                'Binding': 'Vinyl',
                'Brand': 'Hollywood Records',
                'Format': 'Soundtrack',
                'Genre': 'Soundtrack',
                'ItemDimensions': {
                    'Height': {
                        'Units': 'inches',
                        'value': 0.28
                    },
                    'Length': {
                        'Units': 'inches',
                        'value': 12.4
                    },
                    'Width': {
                        'Units': 'inches',
                        'value': 12.24
                    },
                    'Weight': {
                        'Units': 'pounds',
                        'value': 0.48
                    }
                },
                'IsAdultProduct': False,
                'Label': 'Hollywood Records',
                'Languages': [
                    {'Name': 'english', 'Type': 'Unknown'}
                ],
                'ListPrice': {
                    'Amount': 21.98,
                    'CurrencyCode': 'USD'
                },
                'Manufacturer': 'Hollywood Records',
                'NumberOfDiscs': 1,
                'NumberOfItems': 1,
                'PackageDimensions': {
                    'Height': {
                        'Units': 'inches',
                        'value': 1.1
                    },
                    'Length': {
                        'Units': 'inches',
                        'value': 15.04
                    },
                    'Width': {
                        'Units': 'inches',
                        'value': 12.72
                    },
                    'Weight': {
                        'Units': 'pounds',
                        'value': 0.93
                    }
                },
                'PackageQuantity': 1,
                'PartNumber': 'WA-36076758',
                'ProductGroup': 'Music',
                'ProductTypeName': 'ABIS_MUSIC',
                'PublicationDate': '2018-05-18',
                'Publisher': 'Hollywood Records',
                'ReleaseDate': '2018-05-18',
                'SmallImage': {
                    'URL': 'http://ecx.images-amazon.com/images/I/61zEepwLqqL._SL75_.jpg',
                    'Height': {
                        'Units': 'pixels',
                        'value': 75
                    },
                    'Width': {
                        'Units': 'pixels',
                        'value': 75
                    }
                },
                'Studio': 'Hollywood Records',
                'Title': 'Black Panther (Original Score) [LP]'
            },
            'SalesRankings': [
                {'ProductCategoryId': 'music_display_on_website', 'Rank': 36231},
                {'ProductCategoryId': '42', 'Rank': 2172},
            ]
        },
        'B077SXWSRP': {
            'ItemAttributes': {
                'Binding': 'Electronics',
                'Brand': 'Amazon',
                'Color': 'Charcoal',
                'DisplaySize': {
                    'Units': 'inches',
                    'value': 10.1
                },
                'HardDiskSize': {
                    'Units': 'GB',
                    'value': 8.0
                },
                'IsAdultProduct': False,
                'Label': 'Amazon',
                'ListPrice': {
                    'Amount': 229.99,
                    'CurrencyCode': 'USD'
                },
                'Manufacturer': 'Amazon',
                'Model': 'DW84JL',
                'PackageDimensions': {
                    'Height': {
                        'Units': 'inches',
                        'value': 4.96
                    },
                    'Length': {
                        'Units': 'inches',
                        'value': 10.63
                    },
                    'Width': {
                        'Units': 'inches',
                        'value': 9.88
                    },
                    'Weight': {
                        'Units': 'pounds',
                        'value': 6.17
                    }
                },
                'PackageQuantity': 1,
                'PartNumber': '53-007383',
                'ProductGroup': 'Amazon Home',
                'ProductTypeName': 'DIGITAL_DEVICE_3',
                'Publisher': 'Amazon',
                'ReleaseDate': '2018-10-11',
                'SmallImage': {
                    'URL': 'http://ecx.images-amazon.com/images/I/51899c1BCYL._SL75_.jpg',
                    'Height': {
                        'Units': 'pixels',
                        'value': 75
                    },
                    'Width': {
                        'Units': 'pixels',
                        'value': 75
                    }
                },
                'Studio': 'Amazon',
                'Title': u'Echo Show (2nd Gen) – Premium sound and a vibrant 10.1” HD screen - Charcoal'
            },
            'SalesRankings': [
                {'ProductCategoryId': 'amazon_devices_display_on_website', 'Rank': 38},
                {'ProductCategoryId': 'ce_display_on_website', 'Rank': 104},
                {'ProductCategoryId': 'wireless_display_on_website', 'Rank': 362},
                {'ProductCategoryId': '9818047011', 'Rank': 11},
                {'ProductCategoryId': '7073956011', 'Rank': 14},
            ]
        },
        'B07DPM9N6F': {
            'ItemAttributes': {
                'Binding': 'Apparel',
                'Brand': 'Eanklosco',
                'Color': 'Grey',
                'Department': 'womens',
                'IsAdultProduct': False,
                'PackageDimensions': {
                    'Height': {
                        'Units': 'inches',
                        'value': 2.2
                    },
                    'Length': {
                        'Units': 'inches',
                        'value': 9.1
                    },
                    'Width': {
                        'Units': 'inches',
                        'value': 4.4
                    },
                    'Weight': {
                        'Units': 'pounds',
                        'value': 0.6
                    }
                },
                'ProductGroup': 'Apparel',
                'ProductTypeName': 'SHIRT',
                'Size': 'Medium',
                'SmallImage': {
                    'URL': 'http://ecx.images-amazon.com/images/I/41wImP7nTOL._SL75_.jpg',
                    'Height': {
                        'Units': 'pixels',
                        'value': 75
                    },
                    'Width': {
                        'Units': 'pixels',
                        'value': 48
                    }
                },
                'Title': 'Eanklosco Womens Casual Short Sleeve Plain Pocket V Neck T Shirt Tunic Dress (Grey, M)'
            },
            'SalesRankings': [
                {'ProductCategoryId': 'fashion_display_on_website', 'Rank': 15264},
                {'ProductCategoryId': '1044544', 'Rank': 351},
                {'ProductCategoryId': '2346727011', 'Rank': 416},
                {'ProductCategoryId': '7581668011', 'Rank': 8835},
            ]
        },
        'B079TGL2BZ': {
            'ItemAttributes': {
                'AspectRatio': '16:9',
                'Binding': 'Personal Computers',
                'Brand': 'Acer',
                'Color': 'Obsidian Black',
                'CPUManufacturer': 'Intel',
                'CPUSpeed': {
                    'Units': 'GHz',
                    'value': 2.2
                },
                'CPUType': 'core_i3',
                'DisplaySize': {
                    'Units': 'inches',
                    'value': 15.6
                },
                'HardDiskInterface': 'serial_ata',
                'HardDiskSize': {
                    'Units': 'GB',
                    'value': 1000.0
                },
                'ItemDimensions': {
                    'Height': {
                        'Units': 'inches',
                        'value': 1.19
                    },
                    'Length': {
                        'Units': 'inches',
                        'value': 15.02
                    },
                    'Width': {
                        'Units': 'inches',
                        'value': 10.2
                    },
                    'Weight': {
                        'Units': 'pounds',
                        'value': 5.27
                    }
                },
                'IsAdultProduct': False,
                'Label': 'Acer',
                'ListPrice': {
                    'Amount': 379.99,
                    'CurrencyCode': 'USD'
                },
                'Manufacturer': 'Acer',
                'Model': 'E5-576-392H',
                'NumberOfItems': 1,
                'OperatingSystem': 'Windows 10',
                'PackageDimensions': {
                    'Height': {
                        'Units': 'inches',
                        'value': 2.5
                    },
                    'Length': {
                        'Units': 'inches',
                        'value': 19.5
                    },
                    'Width': {
                        'Units': 'inches',
                        'value': 12.2
                    },
                    'Weight': {
                        'Units': 'pounds',
                        'value': 6.95
                    }
                },
                'PackageQuantity': 1,
                'PartNumber': 'E5-576-392H',
                'ProcessorCount': 2,
                'ProductGroup': 'Personal Computer',
                'ProductTypeName': 'NOTEBOOK_COMPUTER',
                'Publisher': 'Acer',
                'ReleaseDate': '2018-09-01',
                'Size': 'Intel i3/6GB/1TB HDD',
                'SmallImage': {
                    'URL': 'http://ecx.images-amazon.com/images/I/41MwXPqLhbL._SL75_.jpg',
                    'Height': {
                        'Units': 'pixels',
                        'value': 75
                    },
                    'Width': {
                        'Units': 'pixels',
                        'value': 75
                    }
                },
                'Studio': 'Acer',
                'SystemMemorySize': {
                    'Units': 'GB',
                    'value': 6.0
                },
                'SystemMemoryType': 'ddr3_sdram',
                'Title': 'Acer Aspire E 15, 15.6" Full HD, 8th Gen Intel Core i3-8130U, 6GB RAM Memory, 1TB HDD, 8X DVD, E5-576-392H',
                'Warranty': 'One-year International Travelers Limited Warranty (ITW)'
            },
            'SalesRankings': [
                {'ProductCategoryId': 'pc_display_on_website', 'Rank': 24},
                {'ProductCategoryId': 'ce_display_on_website', 'Rank': 75},
                {'ProductCategoryId': '13896615011', 'Rank': 1},
            ]
        },
        'B06XH3YVND': {
            'ItemAttributes': {
                'Binding': 'Lawn & Patio',
                'Brand': 'Christopher Knight Home',
                'Color': 'Grey',
                'ItemDimensions': {
                    'Height': {
                        'Units': 'inches',
                        'value': 18.25
                    },
                    'Length': {
                        'Units': 'inches',
                        'value': 40
                    },
                    'Width': {
                        'Units': 'inches',
                        'value': 24
                    },
                    'Weight': None
                },
                'Label': 'GDF Studio',
                'ListPrice': {
                    'Amount': 472.58,
                    'CurrencyCode': 'USD'
                },
                'Manufacturer': 'GDF Studio',
                'MaterialType': 'Wood',
                'Model': '300251',
                'PackageDimensions': {
                    'Height': {
                        'Units': 'inches',
                        'value': 20.0
                    },
                    'Length': {
                        'Units': 'inches',
                        'value': 46.0
                    },
                    'Width': {
                        'Units': 'inches',
                        'value': 26.0
                    },
                    'Weight': {
                        'Units': 'pounds',
                        'value': 136.0
                    }
                },
                'PackageQuantity': 1,
                'PartNumber': '300251',
                'ProductGroup': 'Lawn & Patio',
                'ProductTypeName': 'OUTDOOR_LIVING',
                'Publisher': 'GDF Studio',
                'SmallImage': {
                    'URL': 'http://ecx.images-amazon.com/images/I/3167tUUQSKL._SL75_.jpg',
                    'Height': {
                        'Units': 'pixels',
                        'value': 75
                    },
                    'Width': {
                        'Units': 'pixels',
                        'value': 75
                    }
                },
                'Studio': 'GDF Studio',
                'Title': 'Christopher Knight Home 300251 Manarola 4-Piece Outdoor Acacia Wood Chat Set | in Teak Finish/Grey'
            },
            'SalesRankings': [
                {'ProductCategoryId': 'lawn_and_garden_display_on_website', 'Rank': 16410},
                {'ProductCategoryId': 'home_garden_display_on_website', 'Rank': 63919},
                {'ProductCategoryId': '16135380011', 'Rank': 47},
            ]
        },
        'B01NCJSM2T': {
            'ItemAttributes': {
                'Binding': 'Health and Beauty',
                'Brand': 'Cascade',
                'Color': 'Na',
                'Flavor': 'Fresh Scent',
                'ItemDimensions': {
                    'Height': {
                        'Units': 'inches',
                        'value': 7.25
                    },
                    'Length': {
                        'Units': 'inches',
                        'value': 5.5
                    },
                    'Width': {
                        'Units': 'inches',
                        'value': 6.75
                    },
                    'Weight': {
                        'Units': 'pounds',
                        'value': 3.3
                    }
                },
                'IsAdultProduct': False,
                'IsAutographed': False,
                'IsMemorabilia': False,
                'Label': 'Cascade',
                'ListPrice': {
                    'Amount': 18.99,
                    'CurrencyCode': 'USD'
                },
                'Manufacturer': 'Cascade',
                'Model': 'SPPPOA066638',
                'NumberOfItems': 1,
                'PackageDimensions': {
                    'Height': {
                        'Units': 'inches',
                        'value': 5.5
                    },
                    'Length': {
                        'Units': 'inches',
                        'value': 7.3
                    },
                    'Width': {
                        'Units': 'inches',
                        'value': 6.7
                    },
                    'Weight': {
                        'Units': 'pounds',
                        'value': 3.3
                    }
                },
                'PackageQuantity': 1,
                'PartNumber': 'SPPPOA066638',
                'ProductGroup': 'Health and Beauty',
                'ProductTypeName': 'HEALTH_PERSONAL_CARE',
                'PublicationDate': '2016-10-24',
                'Publisher': 'Cascade',
                'ReleaseDate': '2016-10-24',
                'Size': '78 Count',
                'SmallImage': {
                    'URL': 'http://ecx.images-amazon.com/images/I/51mkHgtthVL._SL75_.jpg',
                    'Height': {
                        'Units': 'pixels',
                        'value': 75
                    },
                    'Width': {
                        'Units': 'pixels',
                        'value': 75
                    }
                },
                'Studio': 'Cascade',
                'Title': 'Cascade Complete ActionPacs Dishwasher Detergent, Fresh Scent, 78 Count'
            },
            'SalesRankings': [
                {'ProductCategoryId': 'health_and_beauty_display_on_website', 'Rank': 1},
                {'ProductCategoryId': '353413011', 'Rank': 1},
                {'ProductCategoryId': '15693671', 'Rank': 1},
            ]
        },
        'B076SVC7SN': {
            'ItemAttributes': {
                'Binding': 'Tools & Home Improvement',
                'Brand': 'LuminoLite',
                'Color': 'Classic Black',
                'ItemDimensions': {
                    'Height': {
                        'Units': 'inches',
                        'value': 5.6
                    },
                    'Length': {
                        'Units': 'inches',
                        'value': 2.56
                    },
                    'Width': {
                        'Units': 'inches',
                        'value': 1.5
                    },
                    'Weight': {
                        'Units': 'pounds',
                        'value': 0.13
                    }
                },
                'Label': 'LuminoLite',
                'ListPrice': {
                    'Amount': 39.99,
                    'CurrencyCode': 'USD'
                },
                'Manufacturer': 'LuminoLite',
                'MaterialType': 'Plastic',
                'Model': 'B076SVC7SN',
                'NumberOfItems': 1,
                'PackageDimensions': {
                    'Height': {
                        'Units': 'inches',
                        'value': 1.75
                    },
                    'Length': {
                        'Units': 'inches',
                        'value': 4.0
                    },
                    'Width': {
                        'Units': 'inches',
                        'value': 3.6
                    },
                    'Weight': {
                        'Units': 'pounds',
                        'value': 0.3
                    }
                },
                'PackageQuantity': 1,
                'PartNumber': 'BL-06',
                'ProductGroup': 'Home Improvement',
                'ProductTypeName': 'HOME_LIGHTING_AND_LAMPS',
                'Publisher': 'LuminoLite',
                'SmallImage': {
                    'URL': 'http://ecx.images-amazon.com/images/I/41STYinO70L._SL75_.jpg',
                    'Height': {
                        'Units': 'pixels',
                        'value': 75
                    },
                    'Width': {
                        'Units': 'pixels',
                        'value': 75
                    }
                },
                'Studio': 'LuminoLite',
                'Title': 'LuminoLite B076SVC7SN Rechargeable 3000K Warm 6 LED Book, Easy Clip Lights Bed. 3 Brightness Eye-Care, 2.1 oz Lightweight, 20 Hours Reading. Perfect for Bookworms & Kids, Classic Black',
                'Warranty': 'Na.'
            },
            'SalesRankings': [
                {'ProductCategoryId': 'home_improvement_display_on_website', 'Rank': 26},
                {'ProductCategoryId': '1063290', 'Rank': 1},
            ]
        },
        'B01JZXWF32': {
            'ItemAttributes': {
                'Binding': 'Kitchen',
                'Brand': 'KitchenAid',
                'Label': 'KitchenAid',
                'Manufacturer': 'KitchenAid',
                'MaterialType': 'Stainless Steel',
                'PackageQuantity': 1,
                'ProductGroup': 'Kitchen',
                'ProductTypeName': 'KITCHEN',
                'Publisher': 'KitchenAid',
                'SmallImage': {
                    'URL': 'http://ecx.images-amazon.com/images/I/31qdhLwbetL._SL75_.jpg',
                    'Height': {
                        'Units': 'pixels',
                        'value': 75
                    },
                    'Width': {
                        'Units': 'pixels',
                        'value': 75
                    }
                },
                'Studio': 'KitchenAid',
                'Title': 'KitchenAid KC351OHOBA Multi-Purpose Scissors Stainless Steel Kitchen Shears with Blade Cover and Soft Grip Handles'
            },
            'SalesRankings': [
                {'ProductCategoryId': 'kitchen_display_on_website', 'Rank': 63},
                {'ProductCategoryId': 'home_garden_display_on_website', 'Rank': 229},
                {'ProductCategoryId': '289860', 'Rank': 1},
                {'ProductCategoryId': '3744031', 'Rank': 2},
            ]
        },
        'B07BPQR892': {
            'ItemAttributes': {
                'Binding': 'Misc.',
                'Brand': 'GM CLIMBING',
                'Color': 'Gray',
                'IsAdultProduct': False,
                'IsMemorabilia': False,
                'Label': 'GM CLIMBING',
                'Manufacturer': 'GM CLIMBING',
                'MaterialType': 'nylon',
                'PackageDimensions': {
                    'Height': {
                        'Units': 'inches',
                        'value': 1.6
                    },
                    'Length': {
                        'Units': 'inches',
                        'value': 6.0
                    },
                    'Width': {
                        'Units': 'inches',
                        'value': 3.5
                    },
                    'Weight': {
                        'Units': 'pounds',
                        'value': 0.3
                    }
                },
                'PartNumber': 'GM16013gray',
                'ProductGroup': 'Sports',
                'ProductTypeName': 'OUTDOOR_RECREATION_PRODUCT',
                'Publisher': 'GM CLIMBING',
                'Size': '60cm / 24inch | Pack of 3',
                'SmallImage': {
                    'URL': 'http://ecx.images-amazon.com/images/I/51-dRx4VrfL._SL75_.jpg',
                    'Height': {
                        'Units': 'pixels',
                        'value': 75
                    },
                    'Width': {
                        'Units': 'pixels',
                        'value': 75
                    }
                },
                'Studio': 'GM CLIMBING',
                'Title': 'GM CLIMBING Pack of 3 16mm Nylon Sling Runner 60cm / 24inch (Gray)'
            },
            'SalesRankings': [
                {'ProductCategoryId': 'sports_display_on_website', 'Rank': 4374},
                {'ProductCategoryId': '2368083011', 'Rank': 2},
            ]
        },
        'B002QYW8LW': {
            'ItemAttributes': {
                'Binding': 'Baby Product',
                'Brand': 'Baby Banana',
                'Color': 'Yellow',
                'Department': 'baby-boys',
                'ItemDimensions': {
                    'Height': {
                        'Units': 'inches',
                        'value': 7.87
                    },
                    'Length': {
                        'Units': 'inches',
                        'value': 4.33
                    },
                    'Width': {
                        'Units': 'inches',
                        'value': 0.39
                    },
                    'Weight': {
                        'Units': 'pounds',
                        'value': 0.09
                    }
                },
                'IsAdultProduct': False,
                'Label': 'Baby Banana',
                'Languages': [
                    {'Name': 'english', 'Type': 'Unknown'}
                ],
                'ListPrice': {
                    'Amount': 8.49,
                    'CurrencyCode': 'USD'
                },
                'Manufacturer': 'Baby Banana',
                'ManufacturerMaximumAge': {
                    'Units': 'months',
                    'value': 24.0
                },
                'ManufacturerMinimumAge': {
                    'Units': 'months',
                    'value': 36.0
                },
                'MaterialType': 'Silicone',
                'Model': 'BR003',
                'NumberOfItems': 1,
                'PackageDimensions': {
                    'Height': {
                        'Units': 'inches',
                        'value': 0.01
                    },
                    'Length': {
                        'Units': 'inches',
                        'value': 8.0
                    },
                    'Width': {
                        'Units': 'inches',
                        'value': 4.0
                    },
                    'Weight': {
                        'Units': 'pounds',
                        'value': 0.1
                    }
                },
                'PackageQuantity': 1,
                'PartNumber': '895872001145',
                'ProductGroup': 'Baby Product',
                'ProductTypeName': 'BABY_PRODUCT',
                'Publisher': 'Baby Banana',
                'ReleaseDate': '2015-04-02',
                'Size': '8',
                'SmallImage': {
                    'URL': 'http://ecx.images-amazon.com/images/I/316WpcHV%2BHL._SL75_.jpg',
                    'Height': {
                        'Units': 'pixels',
                        'value': 75
                    },
                    'Width': {
                        'Units': 'pixels',
                        'value': 44
                    }
                },
                'Studio': 'Baby Banana',
                'Title': 'Baby Banana Infant Training Toothbrush and Teether'
            },
            'SalesRankings': [
                {'ProductCategoryId': 'baby_product_display_on_website', 'Rank': 21},
                {'ProductCategoryId': '17720258011', 'Rank': 1},
                {'ProductCategoryId': '166861011', 'Rank': 2},
            ]
        },
    }

@pytest.fixture(scope='session')
def target_request_report_result():
    return {
        'report_type': '_GET_FLAT_FILE_OPEN_LISTINGS_DATA_',
        'status': '_SUBMITTED_',
        'scheduled': False,
        'report_request_id': '220642017974',
        'submitted_date': '2019-03-19T18:16:38+00:00',
        'start_date': '2019-03-19T18:16:38+00:00',
        'end_date': '2019-03-19T18:16:38+00:00'
    }

@pytest.fixture(scope='session')
def target_report_request_list_result():
    return {
        'has_next': False,
        'report_request_info': {
            'report_type': '_GET_FLAT_FILE_OPEN_LISTINGS_DATA_',
            'report_processing_status': '_DONE_',
            'scheduled': False,
            'report_request_id': '220642017974',
            'started_processing_date': '2019-03-19T18:16:43+00:00',
            'submitted_date': '2019-03-19T18:16:38+00:00',
            'start_date': '2019-03-19T18:16:38+00:00',
            'completed_date': '2019-03-19T18:16:49+00:00',
            'generated_report_id': '14072791674017974',
            'end_date': '2019-03-19T18:16:38+00:00'
        }
    }

@pytest.fixture(scope='session')
def target_report_list_result():
    return {
        'has_next': False,
        'report_infos': [
            {
                'report_type': '_GET_DATE_RANGE_FINANCIAL_TRANSACTION_DATA_',
                'acknowledged': False,
                'report_id': '16366091101018136',
                'available_date': '2019-08-28T22:47:35+00:00',
                'report_request_id': '50251018136'
            },
            {
                'report_type': '_GET_DATE_RANGE_FINANCIAL_TRANSACTION_DATA_',
                'acknowledged': False,
                'report_id': '16350437369018135',
                'available_date': '2019-08-27T22:44:13+00:00',
                'report_request_id': '50222018135'
            },
            {
                'report_type': '_GET_DATE_RANGE_FINANCIAL_TRANSACTION_DATA_',
                'acknowledged': False,
                'report_id': '16355146249018135',
                'available_date': '2019-08-27T22:39:29+00:00',
                'report_request_id': '50221018135'
            },
            {
                'report_type': '_GET_DATE_RANGE_FINANCIAL_TRANSACTION_DATA_',
                'acknowledged': False,
                'report_id': '16348792443018135',
                'available_date': '2019-08-27T22:38:07+00:00',
                'report_request_id': '50220018135'
            },
            {
                'report_type': '_GET_DATE_RANGE_FINANCIAL_TRANSACTION_DATA_',
                'acknowledged': False,
                'report_id': '16355173199018135',
                'available_date': '2019-08-27T22:26:52+00:00',
                'report_request_id': '50219018135'
            },
        ]
    }


@pytest.fixture
def target_product_categories():
    return [
        [
            {'name': 'Health & Household', 'id': '3760901'},
            {'name': 'Products', 'id': '3760931'},
            {'name': 'Health Care', 'id': '3760941'},
            {'name': 'Alternative Medicine', 'id': '13052911'},
            {'name': 'Acupuncture', 'id': '13052921'},
        ]
    ]
